Changelog
=========

All notable changes to this project will be documented in this file.
The format roughly follows `Keep a Changelog <https://keepachangelog.com/en/1.1.0/>`_
and adheres to semantic versioning where possible.


25.12.01 - 2025-12-01
------------------

Fixed
~~~~~

- Predictions now use the optimized threshold computed during training (via Youden's J statistic) instead of hardcoded 0.5. Applies to all model types and prediction modes.


25.11.23 - 2025-11-23
------------------

- First public release of AuToMaR.
